Skip to contents

Returns the end of a confidence interval that lies closer to zero, which is the conservative effect a follow-up study should be powered on. When the interval spans the null there is nothing to power on and NA is returned.

Usage

cr_conservative_effect(ci_low, ci_high)

Arguments

ci_low

Numeric vector of lower interval bounds.

ci_high

Numeric vector of upper interval bounds.

Value

A numeric vector the length of the recycled inputs.

Examples

cr_conservative_effect(c(-1.8, -0.4), c(-0.6, 0.9))
#> [1] -0.6   NA