Combines cell count per well, area distributions and intensity distributions into a single multi-panel figure.
Examples
exp <- cr_example_experiment(seed = 1, n_cells_per_well = 30)
cr_plot_qc(exp, channel = "marker_1")
Combines cell count per well, area distributions and intensity distributions into a single multi-panel figure.
exp <- cr_example_experiment(seed = 1, n_cells_per_well = 30)
cr_plot_qc(exp, channel = "marker_1")