Effect size at the confidence bound nearer the null
Source:R/statistics-power.R
cr_conservative_effect.RdReturns the end of a confidence interval that lies closer to zero,
which is the conservative effect a follow-up study should be powered
on. When the interval spans the null there is nothing to power on
and NA is returned.
See also
Other power:
cr_power(),
cr_power_analysis(),
cr_power_grid()