Normalizes the several shapes a QC record can take — an experiment's QC log, a gate object, or a plain data frame — into one tibble suitable for a supplement.
Value
A tibble. For a list of several data frames the elements are
stacked and identified by a component column.
See also
Other reporting:
cr_export_plots(),
cr_export_results(),
cr_export_tables(),
cr_render_report(),
cr_report(),
cr_tables()
Examples
exp <- cr_example_experiment(seed = 1, n_cells_per_well = 20)
exp <- cr_filter_cells(exp, area > 100)
cr_table_qc(exp)
#> # A tibble: 1 × 7
#> step parameters cells_before cells_after cells_removed percent_removed
#> <chr> <chr> <int> <int> <int> <dbl>
#> 1 cr_filter_c… list(area… 1961 1828 133 6.78
#> # ℹ 1 more variable: timestamp <dttm>